@@ -1,14 +1,15 @@
-//
-// C++ Interface: quickbuttonsconfigcontroller
-//
-// Description:
-//
-//
-// Author: Dario Abatianni <eisfuchs@tigress.com>, (C) 2006
-//
-// Copyright: See COPYING file that comes with this distribution
-//
-//
+/*
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
+*/
+
+/*
+  Copyright (C) 2006 Dario Abatianni <eisfuchs@tigress.com>
+  Copyright (C) 2006 John Tapsell <johnflux@gmail.com>
+*/
+
 #ifndef QUICKBUTTONSCONFIG_H
 #define QUICKBUTTONSCONFIG_H
 
@@ -40,14 +41,15 @@ class QuickButtons_Config : public QuickButtons_ConfigUI, public KonviSettingsPa
     void entrySelected(QListViewItem* quickButtonEntry);
     void nameChanged(const QString& newName);
     void actionChanged(const QString& newAction);
-
-  private:
-    void setButtonsListView(const QStringList &buttonList);
+    void addEntry();
+    void removeEntry();
 
   protected:
-    bool m_newItemSelected;
-    QStringList m_oldButtonList;
+    void setButtonsListView(const QStringList &buttonList);
 
+    bool m_newItemSelected;
+
+    QStringList m_oldButtonList;
     QStringList currentButtonList();
 };
 
