@@ -6,11 +6,8 @@
 */
 
 /*
-  Launches shell scripts
-  begin:     Mit Mr 12 2003
-  copyright: (C) 2003 by Dario Abatianni
-             (C) 2004 by Peter Simonsson
-  email:     eisfuchs@tigress.com
+  Copyright (C) 2003 Dario Abatianni <eisfuchs@tigress.com>
+  Copyright (C) 2004 Peter Simonsson <psn@linux.se>
 */
 
 #include <qobject.h>
